Stan Math Library: stan/math/prim/mat/err/check_square.hpp Source File

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

check_square.hpp
Go to the documentation of this file.
1 #ifndef STAN_MATH_PRIM_MAT_ERR_CHECK_SQUARE_HPP
2 #define STAN_MATH_PRIM_MAT_ERR_CHECK_SQUARE_HPP
3
4 #include <stan/math/prim/mat/fun/Eigen.hpp>
5 #include <stan/math/prim/scal/err/check_size_match.hpp>
6 #include <sstream>
7
8 namespace stan {
9 namespace math {
10
26 template <typename T_y>
27 inline bool
28 check_square(const char* function,
29 const char* name,
30 const Eigen::Matrix<T_y, Eigen::Dynamic, Eigen::Dynamic>& y) {
31 check_size_match(function,
32 "Expecting a square matrix; rows of ", name, y.rows(),
33 "columns of ", name, y.cols());
34 return true;
35 }
36
37 }
38 }
39 #endif
check_size_match.hpp
stan
Definition: log_sum_exp.hpp:8
stan::math::check_size_match
bool check_size_match(const char *function, const char *name_i, T_size1 i, const char *name_j, T_size2 j)
Return true if the provided sizes match.
Definition: check_size_match.hpp:30
Eigen.hpp
stan::math::check_square
bool check_square(const char *function, const char *name, const Eigen::Matrix< T_y, Eigen::Dynamic, Eigen::Dynamic > &y)
Return true if the specified matrix is square.
Definition: check_square.hpp:28

[ Stan Home Page ] © 2011–2016, Stan Development Team.